@@ -1,6 +1,6 @@
 package Spreadsheet::XLSX::Reader::LibXML::XMLReader::SharedStrings;
 our $AUTHORITY = 'cpan:JANDREW';
-use version; our $VERSION = qv('v0.38.16');
+use version; our $VERSION = qv('v0.38.18');
 ###LogSD	warn "You uncovered internal logging statements for Spreadsheet::XLSX::Reader::LibXML::XMLReader::SharedStrings-$VERSION";
 
 use 5.010;
@@ -8,12 +8,13 @@ use Moose;
 use MooseX::StrictConstructor;
 use MooseX::HasDefaults::RO;
 use Types::Standard qw(
-		Int		Bool		HashRef			is_HashRef		ArrayRef	Enum
+		Int		Bool		HashRef			is_HashRef		ArrayRef	Enum	is_Int
     );
 use Carp qw( confess );
 use lib	'../../../../../../lib';
 ###LogSD	use Log::Shiras::Telephone;
 ###LogSD	use Log::Shiras::UnhideDebug;
+###LogSD	sub get_class_space{ 'SharedStrings' }
 extends	'Spreadsheet::XLSX::Reader::LibXML::XMLReader';
 
 #########1 Public Attributes  3#########4#########5#########6#########7#########8#########9
@@ -47,6 +48,8 @@ sub get_shared_string_position{
 	if( !defined $position ){
 		$self->set_error( "Requested shared string position required - none passed" );
 		return undef;
+	}elsif( !is_Int( $position ) ){
+		confess "The passed position -$position- is not an integer";
 	}
 	###LogSD	$phone->talk( level => 'debug', message => [
 	###LogSD		"Getting the sharedStrings position: $position" ] );
@@ -231,11 +234,6 @@ has _cache_completed =>(
 
 #########1 Private Methods    3#########4#########5#########6#########7#########8#########9
 
-###LogSD	sub BUILD {
-###LogSD	    my $self = shift;
-###LogSD			$self->set_class_space( 'SharedStrings' );
-###LogSD	}
-
 sub _load_unique_bits{
 	my( $self, ) = @_;
 	###LogSD	my	$phone = Log::Shiras::Telephone->new( name_space =>
